SingularAdData class

Inheritance

Constructors

SingularAdData(dynamic adPlatform, dynamic currency, dynamic revenue)

Properties

entries → Iterable<MapEntry<String, dynamic>>
The map entries of this Map.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether there is no key/value pair in the map.
no setterinherited
isNotEmpty → bool
Whether there is at least one key/value pair in the map.
no setterinherited
keys → Iterable<String>
The keys of this Map.
no setteroverride
length → int
The number of key/value pairs in the map.
no setterinherited
requiredParams → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → Iterable
The values of this Map.
no setterinherited

Methods

addAll(Map<String, dynamic> other) → void
Adds all key/value pairs of other to this map.
inherited
addEntries(Iterable<MapEntry<String, dynamic>> newEntries) → void
Adds all key/value pairs of newEntries to this map.
inherited
cast<RK, RV>() → Map<RK, RV>
Provides a view of this map as having RK keys and RV instances, if necessary.
inherited
clear() → void
Removes all entries from the map.
override
containsKey(Object? key) → bool
Whether this map contains the given key.
inherited
containsValue(Object? value) → bool
Whether this map contains the given value.
inherited
forEach(void action(String key, dynamic value)) → void
Applies action to each key/value pair of the map.
inherited
hasRequiredParams() → bool
map<K2, V2>(MapEntry<K2, V2> transform(String key, dynamic value)) → Map<K2, V2>
Returns a new map where all entries of this map are transformed by the given convert function.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putIfAbsent(String key, dynamic ifAbsent()) → dynamic
Look up the value of key, or add a new entry if it isn't there.
inherited
remove(Object? key) → dynamic
Removes key and its associated value, if present, from the map.
override
removeWhere(bool test(String key, dynamic value)) → void
Removes all entries of this map that satisfy the given test.
inherited
toString() → String
A string representation of this object.
inherited
update(String key, dynamic update(dynamic value), {dynamic ifAbsent()?}) → dynamic
Updates the value for the provided key.
inherited
updateAll(dynamic update(String key, dynamic value)) → void
Updates all values.
inherited
withAdGroupId(String adGroupId) → dynamic
withAdGroupName(String adGroupName) → dynamic
withAdGroupPriority(String adGroupPriority) → dynamic
withAdGroupType(String adGroupType) → dynamic
withAdPlacementName(String adPlacementName) → dynamic
withAdType(String adType) → dynamic
withAdUnitId(String adUnitId) → dynamic
withAdUnitName(String adUnitName) → dynamic
withImpressionId(String impressionId) → dynamic
withLimitDataSharing(bool shouldLimitDataSharing) → dynamic
withNetworkName(String networkName) → dynamic
withPlacementId(String placementId) → dynamic
withPrecision(String precision) → dynamic

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](Object? key) → dynamic
The value for the given key, or null if key is not in the map.
override
operator []=(String key, dynamic value) → void
Associates the key with the given value.
override